@@ -57,7 +57,7 @@ class App(object):
         handler = self._handler(func, method, **kwargs)
         self.app.api_route(path=path, methods=[method])(handler)
 
-    def _handler(self, func, method='GET', result_key='result', **kwargs):
+    def _handler(self, func, method='GET', result_key='Result', **kwargs):
         """
 
         :param func:
@@ -83,7 +83,7 @@ class App(object):
 
         return handler
 
-    def _try_func(self, kwargs, func, result_key='result', **kwargs_):
+    def _try_func(self, kwargs, func, result_key='Result', **kwargs_):
         input = kwargs
         output = OrderedDict()
 
@@ -91,11 +91,11 @@ class App(object):
             output['RequestParams'] = input
 
         try:
-            output['suceess'] = 1
+            output['Success'] = 1
             output[result_key] = func(**input)
 
         except Exception as error:
-            output['suceess'] = 0
+            output['Success'] = 0
             output['Error'] = error
             output['ErrorPlus'] = format_exc().strip()
 
